@@ -1,6 +1,6 @@
 package App::Cerberus;
 {
-  $App::Cerberus::VERSION = '0.05';
+  $App::Cerberus::VERSION = '0.06';
 }
 
 use strict;
@@ -67,7 +67,7 @@ App::Cerberus - A pluggable Perl web service to preprocess web requests. Plugins
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 DESCRIPTION
 
@@ -127,7 +127,7 @@ For instance:
         "latitude": "40.7167"
     }
 
-=head2 L<App::Cerbrerus::Plugin::TimeZone>
+=head2 L<App::Cerberus::Plugin::TimeZone>
 
 Uses L<Time::OlsonTZ::Data> to provide the current timezone for the user, and
 it's offset from GMT.
@@ -141,8 +141,8 @@ For instance:
         "gmt_offset": "-14400"
     }
 
-The L<GeoIP|/App::Cerberus::Plugin::GeoIP> plugin must be run before the
-L<TimeZone|/App::Cerberus::Plugin::TimeZone> plugin.
+The L<GeoIP|App::Cerberus::Plugin::GeoIP> plugin must be run before the
+L<TimeZone|App::Cerberus::Plugin::TimeZone> plugin.
 
 =head2 L<App::Cerberus::Plugin::BrowserDetect>
 
@@ -249,6 +249,16 @@ See each L<plugin|PLUGINS> for details of the accepted parameters.
 
 See L<cerberus.pl> for more options.
 
+=head1 SEE ALSO
+
+=over
+
+=item L<App::Cerberus::Client>
+
+=item L<Dancer::Plugin::Cerberus>
+
+=back
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
